<?php

/*

	Plugin Name: Syndicate Out
	Version: 0.3
	Description: Syndicates posts made in any specified category to another WP blog using WordPress' built in XMLRPC functionality.
	Author: Fubra Limited
	Author URI: http://blogs.fubra.com/jonathon/

	TODO: Deal with post updates.
	      Deal with remote comments.

*/

#
#  syndicate_out.php
#
#  Created by Jonathon Wardman on 09-07-2009.
#  Copyright 2009, Fubra Limited. All rights reserved.
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  You may obtain a copy of the License at:
#  http://www.gnu.org/licenses/gpl-3.0.txt
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.


	 // Nothing in this plugin work outside of the admin area, so don't bother
	 // loading it if we're not looking at the admin panel...
if ( is_admin() ) {

	 // Register functions...
	add_action( 'admin_menu', 'syndicate_out_menu' );
	add_action( 'admin_init', 'syndicate_out_register_settings' );
	add_action( 'wp_insert_post', 'syndicate_out_post' );

	 // Admin menu...
	function syndicate_out_menu() {

		add_submenu_page( 'options-general.php', 'Syndicate Out Settings', 'Syndication', 'Administrator', 'syndicate_out', 'syndicate_out_admin' );

	}

	 // Register valid admin options...
	function syndicate_out_register_settings() {

		register_setting( 'syndicate-out-options', 'so_category' );

		register_setting( 'syndicate-out-options', 'so_remote_server', 'so_sanitize_remote_server' );
		register_setting( 'syndicate-out-options', 'so_remote_username' );
		register_setting( 'syndicate-out-options', 'so_remote_password' );

	}

	 // Admin page...
	function syndicate_out_admin() {

		require_once( 'so_options.php' );

	}

	 // Sanitize the remote server (add preceeding http:// and trailing slash if
	 // they're not already there)...
	function so_sanitize_remote_server( $remoteServer ) {

		$remoteServer = trim( $remoteServer );

		if ( substr( $remoteServer, 0, 7 ) != 'http://' ) {
         $remoteServer = 'http://'.$remoteServer;
		}

		if ( substr( $remoteServer, -1 ) != '/' ) {
         $remoteServer .= '/';
		}

		return $remoteServer;

	}

	 // Carry out the syndication on post insert...
	function syndicate_out_post( $postId ) {

		if ( in_category( get_option( 'so_category' ), $postId ) ) {

			$postData = get_post( $postId );

			if ( $postData->post_status == 'publish' ) {
				if ( @include_once( '../wp-includes/class-IXR.php' ) ) {

					$remotePost['title'] = $postData->post_title;
					$remotePost['description'] = $postData->post_content;
					if ($postTags = syndicate_out_get_tags($postId)) {
						$keywords = array();
						foreach ($postTags AS $postTag) {
							$keywords[] = $postTag->name;
						}
						$remotePost['mt_keywords'] = implode(',', $keywords);
					}

					$xmlrpc = new IXR_Client( get_option( 'so_remote_server' ).'xmlrpc.php' );
					$xmlrpc->query( 'metaWeblog.newPost', 1, get_option( 'so_remote_username' ), get_option( 'so_remote_password' ), $remotePost, 1 );

				}
			}

		}

	}

	 // Get a list of tags for this post...
	function syndicate_out_get_tags( $postId ) {

		$terms = get_object_term_cache( $postId, 'post_tag' );
		if ( false === $terms ) {
			$terms = wp_get_object_terms( $postId, 'post_tag' );
		}

		if ( empty( $terms ) ) {
			return false;
		}

		return $terms;

	}

}